@@ -13,7 +13,7 @@ import py
 import pytest
 from PIL import Image
 from weasyprint import CSS, HTML, __main__, default_url_fetcher
-from weasyprint.links import resolve_links
+from weasyprint.pdf.anchors import resolve_links
 from weasyprint.urls import path2url
 
 from .draw import parse_pixels
@@ -464,6 +464,30 @@ def test_partial_pdf_custom_metadata():
     assert b'value' in stdout
 
 
+@pytest.mark.parametrize('html, field', (
+    (b'<input>', b'/Tx'),
+    (b'<input type="checkbox">', b'/Btn'),
+    (b'<textarea></textarea>', b'/Tx'),
+))
+def test_pdf_inputs(html, field):
+    stdout = _run('--pdf-forms - -', html)
+    assert b'AcroForm' in stdout
+    assert field in stdout
+    stdout = _run('- -', html)
+    assert b'AcroForm' not in stdout
+
+
+@pytest.mark.parametrize('css, with_forms, without_forms', (
+    ('appearance: auto', True, True),
+    ('appearance: none', False, False),
+    ('', True, False),
+))
+def test_appearance(css, with_forms, without_forms):
+    html = f'<input style="{css}">'.encode()
+    assert (b'AcroForm' in _run('--pdf-forms - -', html)) is with_forms
+    assert (b'AcroForm' in _run('- -', html)) is without_forms
+
+
 def test_reproducible():
     os.environ['SOURCE_DATE_EPOCH'] = '0'
     stdout1 = _run('- -', b'<body>a<img src=pattern.png>')
@@ -926,6 +950,21 @@ def test_links_11():
         ''', [[]], [{}], [([], [])], base_url=None)
 
 
+@assert_no_logs
+def test_links_12():
+    # Absolute URI with no fragment and the same base URI: keep external URI
+    # Regression test for https://github.com/Kozea/WeasyPrint/issues/1767
+    assert_links(
+        '''
+            <body style="width: 200px">
+            <a href="https://weasyprint.org"
+               style="display: block; margin: 10px 5px">
+        ''',
+        [[('external', 'https://weasyprint.org', (5, 10, 195, 10))]], [{}],
+        [([('external', 'https://weasyprint.org', (5, 10, 195, 10))], [])],
+        base_url='https://weasyprint.org')
+
+
 # Make relative URL references work with our custom URL scheme.
 uses_relative.append('weasyprint-custom')
 
